/************************************************************************
 *
 *  TableStyleConverter.java
 *
 *  Copyright: 2002-2010 by Henrik Just
 *
 *  This file is part of Writer2LaTeX.
 *  
 *  Writer2LaTeX is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *  
 *  Writer2LaTeX is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *  
 *  You should have received a copy of the GNU General Public License
 *  along with Writer2LaTeX.  If not, see <http://www.gnu.org/licenses/>.
 * 
 *  Version 1.2 (2010-05-13)
 *
 */

package w2phtml.xhtml.style;

import w2phtml.office.OfficeReader;
import w2phtml.office.OfficeStyleFamily;
import w2phtml.office.StyleWithProperties;
import w2phtml.office.XMLString;
import w2phtml.util.CSVList;
import w2phtml.xhtml.Converter;
import w2phtml.xhtml.XhtmlConfig;
import w2phtml.xhtml.XhtmlStyleMap;
import w2phtml.xhtml.style.properties.Properties;

/**
 * This class converts OpenDocument table styles to CSS2 styles.
 * Table formatting includes <em>background</em>, <em>alignment</em>,
 * <em>margins</em>, and also <em>width</em>, which is considered elsewhere.
 */
public class TableStyleParser extends StyleWithPropertiesParser {

    /** Create a new <code>TableStyleConverter</code>
     *  @param ofr an <code>OfficeReader</code> to read style information from
     *  @param config the configuration to use
     *  @param converter the main <code>Converter</code> class
     *  @param nType the type of xhtml to use
     */
    public TableStyleParser(OfficeReader ofr, XhtmlConfig config, Converter converter, int nType) {
        super(ofr,config,converter,nType);
        // Style maps for tables are currently not supported.
        this.styleMap = new XhtmlStyleMap();
    }

    /** Get the family of table styles
     *  @return the style family
     */
    public OfficeStyleFamily getStyles() {
        return ofr.getTableStyles();
    }
	
    /** Create default tag name to represent a table object
     *  @param style to use
     *  @return the tag name
     */
    public String getStyleTag() {
        return "table";
    }
	
    /** Convert formatting properties for a specific table style.
     *  @param style the style to convert
     *  @param props the <code>CSVList</code> object to add information to
     *  @param bInherit true if properties should be inherited from parent style(s)
     */
    public void applyProperties(StyleWithProperties style, Properties props, boolean bInherit) {
    	// Page break
    	getParSP().cssPageBreak(style, props, bInherit);
        // Apply background
        getFrameSP().cssBackground(style,props,bInherit);
        // Table-specific properties
        cssTable(style,props,bInherit);
    }
	
    private void cssTable(StyleWithProperties style, Properties props, boolean bInherit){
        // Top and bottom margins
        String sMarginTop = style.getAbsoluteProperty(XMLString.FO_MARGIN_TOP);
        if (sMarginTop!=null) { props.addProperty("margin-top",scale(sMarginTop)); }
        else { props.addProperty("margin-top","0"); }

        String sMarginBottom = style.getAbsoluteProperty(XMLString.FO_MARGIN_BOTTOM);
	    if (sMarginBottom!=null) { props.addProperty("margin-bottom",scale(sMarginBottom)); }
        else { props.addProperty("margin-bottom","0"); }

        // Left and right margins and horizontal alignment
        String sAlign = style.getProperty(XMLString.TABLE_ALIGN);
        String sMarginLeft = style.getAbsoluteProperty(XMLString.FO_MARGIN_LEFT);
        if (sMarginLeft!=null) { sMarginLeft = scale(sMarginLeft); }
        String sMarginRight = style.getAbsoluteProperty(XMLString.FO_MARGIN_RIGHT);
        if (sMarginRight!=null) { sMarginRight = scale(sMarginRight); }

        if ("center".equals(sAlign)) {
		    sMarginLeft = "auto"; sMarginRight = "auto";
        }
        else if ("right".equals(sAlign)) {
		    sMarginLeft = "auto";
        }
        else if ("left".equals(sAlign)) {
		    sMarginRight = "auto";
        }

        if (sMarginLeft!=null) { props.addProperty("margin-left",sMarginLeft); }		
        if (sMarginRight!=null) { props.addProperty("margin-right",sMarginRight); }		
    }
	
}
